@@ -37,7 +37,7 @@ from libdiscid.exceptions import DiscError
 import re
 import warnings
 
-__version__ = '0.4.1'
+__version__ = '1.1'
 
 DEFAULT_DEVICE = libdiscid._discid.default_device()
 """ The default device to use for :func:`DiscId.read` on this platform.
@@ -67,7 +67,7 @@ __discid_version__ = libdiscid._discid.__discid_version__
 """ The version of the underlying libdiscid.
 """
 
-class DiscId(object):
+class DiscId:
   """ Disc information
 
   Class holding all the information obtained from a disc.
